@@ -65,14 +65,14 @@ class LedFxCore(object):
         def log_filter(record):
             return (record.name != "ledfx.api.log") and (record.levelno >= 20)
 
-        self.logqueue = asyncio.Queue(maxsize=100, loop=self.loop)
+        self.logqueue = asyncio.Queue(maxsize=100)
         logqueue_handler = RollingQueueHandler(self.logqueue)
         logqueue_handler.addFilter(log_filter)
         root_logger = logging.getLogger()
         root_logger.addHandler(logqueue_handler)
 
     async def flush_loop(self):
-        await asyncio.sleep(0, loop=self.loop)
+        await asyncio.sleep(0)
 
     def start(self, open_ui=False):
         async_fire_and_forget(self.async_start(open_ui=open_ui), self.loop)
@@ -154,7 +154,7 @@ class LedFxCore(object):
 
         # Fire a shutdown event and flush the loop
         self.events.fire_event(LedFxShutdownEvent())
-        await asyncio.sleep(0, loop=self.loop)
+        await asyncio.sleep(0)
 
         await self.http.stop()
 
